@@ -16,7 +16,7 @@ sub import {
     my($proto, @args) = @_;
     foreach my $package (@args){
 	use_module $package;
-	$GLOBAL_MOCKS{$package} = Test::Mock::Wrapper->new($package);
+	$GLOBAL_MOCKS{$package} = Test::Mock::Wrapper->new($package, preloaded=>1);
     }
 }
 
@@ -85,7 +85,6 @@ version 0.13
     
     print &bar('baz');  # Back to the original Foo::bar (whatever that did)
 
-    
 =head1 DESCRIPTION
 
 This is another module for mocking objects in perl.  It will wrap around an existing object, allowing you to mock any calls
@@ -143,6 +142,50 @@ By default arguments will be a simple copy of @_, use B<clone> to make a deep co
 passed in, the default will not trap the state of the object or reference at the time the method was called, though clone will.
 Naturally using clone will cause a larger memory foot print.
 
+=item wrap_superclass=>qr/REGEX/ (Package Only)
+
+*CAUTION*
+
+This is is a powerful, but potentially problematic feature. By providing wrap_superclass=>qr/REGEX/ the module will mock methods
+called on the wrapped package, even if they are inherited from parent classes.  This option only works when mocking an entire pacakge,
+and cannot work on a single mocked object. The big GOTCHA here happens if the provided REGEX is to broad. It will match as far up the
+heritance tree as perl will allow, including mocking methods in UNIVERSAL which can have adverse effects if not used wisely.
+
+When wrapping a superclass, this module should only mock superclass methods when they are invoked via an object blessed into the
+mocked class...  consider the following example:
+
+    package Pet;
+    
+    sub play {
+	return "fun";
+    }
+    
+    pacakage Dog;
+    use base qw(Pet);
+    
+    sub speak {
+	return "Bark";
+    }
+    
+    package Cat;
+    use base qw(Pet);
+    
+    sub speak {
+	return "Meow";
+    }
+    
+    package main;
+    use Test::Mock::Wrapper;
+    
+    my $mock = Test::Mock::Wrapper->new('Cat', wrap_supercalss=>qr/^Pet/);
+    $mock->addMock('play')->returns('Maybe later');
+    
+    my $cat = Cat->new;
+    my $dog = Dog->new;
+    
+    print $cat->play."\n";   # prints "Maybe Later\n";
+    print $dog->play."\n";   $ prints "Fun\n";
+
 =back
 
 =cut
@@ -165,9 +208,23 @@ sub new {
 	$metaclass->make_mutable if($metaclass->is_immutable);
 
 	$controll->{__metaclass} = $metaclass;
-	
-	foreach my $method_name ($metaclass->get_method_list){
-	    push @{ $controll->{__wrapped_symbols} }, {name => $method_name, symbol => $metaclass->find_method_by_name($method_name)};
+	my(@method_list)=();
+	if ($options{wrap_superclass}) {
+	    (@method_list) = grep(!/DESTROY/, $metaclass->get_all_method_names);
+	    
+	}
+	else {
+	    (@method_list) = $metaclass->get_method_list;
+	}
+	foreach my $method_name (@method_list){
+	    my $symbol = $metaclass->find_method_by_name($method_name);
+	    if ($options{wrap_superclass} ){
+		if($symbol->{package_name} !~ m/$options{wrap_superclass}/) {
+		    next;
+		}
+	    }
+	    
+	    push @{ $controll->{__wrapped_symbols} }, {name => $method_name, symbol => $symbol};
 	    $controll->{__symbols}{$method_name} = $metaclass->find_method_by_name($method_name)->body;
 	    if ($method_name eq 'new') {
 		my $method = $metaclass->remove_method($method_name);
@@ -181,7 +238,14 @@ sub new {
 		
 	    }else{
 		my $method = $metaclass->remove_method($method_name);
-		$metaclass->add_method($method_name, sub{ $controll->_call($method_name, @_); });
+		$metaclass->add_method($method_name, sub{
+		    if($options{preloaded} || (ref($_[0]) && ref($_[0]) eq $object) || $_[0] eq $object){
+			$controll->_call($method_name, @_);
+		    }
+		    else {
+			goto &$controll->{__symbols}{$method_name};
+		    }
+		});
 	    }
 	}
     }
